Lunar Sample Laboratory Facility - Wikipedia

Jump to content

# Lunar Sample Laboratory Facility

4 languages

- العربية
- Français
- Italiano
- Русский

Edit links
Coordinates:
29°33′34″N 95°05′00″W﻿ / ﻿29.5594°N 95.0833°W﻿ / 29.5594; -95.0833
From Wikipedia, the free encyclopedia
NASA facility in Houston, Texas

Lunar Sample Laboratory Facility
Vintage (left) and contemporary (right) glove boxes as seen in 2015
Established | 1979 (1979)
Field of research | Geology
Address | Lyndon B. Johnson Space Center
Location | Houston, Texas, U.S. 29°33′34″N 95°05′00″W﻿ / ﻿29.5594°N 95.0833°W﻿ / 29.5594; -95.0833
ZIP code | 77058
Operating agency | NASA
Website | curator.jsc.nasa.gov/lunar/laboratory_tour.cfm

The Lunar Sample Laboratory Facility (LSLF) is a repository and laboratory facility at NASA's Lyndon B. Johnson Space Center in Houston, Texas, opened in 1979 to house geologic samples returned from the Moon by the Apollo program missions to the lunar surface between 1969 and 1972. The facility preserves most of the 382 kilograms (842 lb) of lunar material returned over the course of Apollo program and other extraterrestrial samples, along with associated data records. It also contains laboratories for processing and studying the samples without contamination.

## History[edit]

Planning for handling returned lunar samples began early in the Apollo program. In 1964, a proposal was made for a small (10 square meters (110 sq ft)) sample receiving laboratory equipped with remote-controlled manipulators operating in a sterile, high-vacuum chamber to prepare samples for distribution to scientists, and this proposal was subsequently expanded to include a clean room with analytical instruments for performing preliminary analyses on the samples.[1]

A committee of the Space Science Board reviewed the idea of a lunar sample receiving laboratory and sought to address multiple concerns. One was the fear that creating a facility with too great a capacity to analyze the samples would discourage distribution of samples to outside researchers and effectively exclude them.[1] In addition, space biologists and the United States Public Health Service expressed concern about "back contamination" of Earth by extraterrestrial microorganisms brought back via returning spacecraft,[2] (although many of the astronauts and scientists involved in the program were skeptical that non-terrestrial microorganisms could survive lunar conditions). To address these issues, the committee in 1965 recommended a laboratory with limited analytical capacity and an ability to quarantine the returning astronauts and samples.[1]

The result of this planning was the Lunar Receiving Laboratory (LRL) in Building 37 at the Johnson Space Center, built to process and conduct basic analysis on lunar materials and to quarantine the materials and astronauts.[1] (The requirement that astronauts be quarantined following their missions was dropped beginning with Apollo 15.) The 8,000-square-meter (86,000 sq ft) LRL was completed in 1967 at a cost of $7.8 million.[1] The LRL was used for study, distribution and safe storage of the samples, but although the LRL had adequate facilities to process samples for the current mission, the facility was not ideal, and it lacked facilities to process or store samples from previous missions.[3] To address some of these concerns, NASA dropped the requirement after Apollo 12 that samples be processed in vacuum (in favor of a simpler-to-work-in nitrogen atmosphere). An additional vault and, subsequently, a new laboratory – the Sample Storage and Processing Laboratory (SSPL) – were built in Building 31 of the Johnson Space Center. All lunar samples were moved from the LRL to Building 31 after the last Apollo mission[1]

Nonetheless, there were still concerns about the adequacy of the facility and about the wisdom of maintaining the entire collection of lunar samples in a single facility that might be vulnerable to natural disasters (especially the hurricanes to which Houston is vulnerable) and military actions. The collection was divided among multiple vaults at the Johnson Space Center while a vault was built in an empty ammunition bunker at Brooks Air Force Base in San Antonio, Texas, as second-site storage. Fourteen percent of the lunar sample collection was moved to this bunker in 1976, transported secretly at night with a police escort in a specially modified passenger bus.[1] This smaller collection of materials remained at Brooks until 2002, when the base was transitioned from military control as part of the Base Realignment and Closure process. The second-site lunar materials were then moved to the White Sands Test Facility, where a new, smaller facility was built inside an existing secure building to house the samples.[3] Of the 382 kilograms (842 lb) of lunar samples returned by the Apollo program, 52 kilograms (115 lb) are currently stored at White Sands.[4]

With a selection of the lunar samples secured offsite, construction began on the LSLF, with state-of-the-art facilities for handling the samples and better protection against natural disasters. The LSLF was constructed in a new annex of Building 31 (Building 31N at the Johnson Space Center) beginning in 1977.[1] Built for a cost of $2.5 million, the building was dedicated on July 20, 1979, the tenth anniversary of the first human Moon landing.[3]

## Features[edit]

Apollo 11 lunar samples cabinet in the storage vault

The two-story, 1,300-square-meter (14,000 sq ft) facility consists of storage vaults for the samples, laboratories for sample preparation and study, a vault for sample data and records, and machinery to supply nitrogen to the cabinets in which the samples are stored and processed.[3][5]

The facility's storage vaults are elevated above anticipated storm-surge sea level heights to protect the samples from threats posed by hurricanes and tornadoes.[6] During hurricane threats, a water-tight door is bolted into the frame of the door to the pristine sample vault in order to protect the samples.[5] The facility takes extensive measures to prevent contamination of the lunar samples. For example:

- All materials used in constructing and equipping the building (including floor coverings, walls, plumbing, light fixtures, and paint) were carefully screened to exclude chemical elements that would pose unacceptable contamination threats to the lunar samples.[6]
- Air in the facility is filtered to remove all suspended particles, and the air in the laboratories and vaults is maintained at slightly higher than atmospheric pressure to keep unfiltered air from entering. The particulate concentration of the air in the various areas is monitored regularly.[5]
- People entering laboratories and vaults are required to don cleanroom suits.[5]
- Most samples are not handled directly. Researchers prepare samples in stainless steel cabinets through multi-layered gloves. The atmosphere in these cabinets is purged by high-purity nitrogen that is continuously monitored for oxygen and moisture contents. When research requires that a sample be exposed to contamination, the sample is kept separate from pristine samples after its return.[6]
- To avoid cross-contamination of samples from different places on the Moon, samples from different missions are not processed together in the same cabinet, but one or more cabinets are designated for processing samples from a particular mission. When cabinets become dusty from extensive processing or are needed for processing samples from a different mission, they are cleaned using ultra-pure water.[5]

The facility has room to store many more lunar samples. NASA anticipates that more samples from the Moon will be brought back and processed and curated in the lab.[3]

## Samples stored at facility and other lunar samples[edit]

The Genesis Rock

The facility is the chief repository of the samples returned by the Apollo program.[5] The Apollo missions to the lunar surface (Apollo 11, Apollo 12, Apollo 14, Apollo 15, Apollo 16, and Apollo 17) returned a total of 382 kilograms (842 pounds) of lunar rocks, core samples, pebbles, sand and lunar surface dust, comprising 2200 individual specimens. Seventy-five percent of the lunar materials returned by Apollo are housed at the Lunar Sample Laboratory Facility, most in pristine condition.[3] Some of the materials have been processed into smaller samples to meet scientific requirements, resulting in more than 110,000 individually cataloged samples.[6]

Perhaps the most notable of the samples stored at the facility is the Genesis Rock, a sample ultimately determined to be nearly as old as the Moon itself.[7] Also at the facility is the sample known as Big Muley, the largest sample returned from the Moon by Apollo.[5]

In addition to the Apollo materials, the Johnson Space Center also houses other extraterrestrial samples:

- Antarctic meteorites collected on ANSMET (ANtarctic Search for METeorites) expeditions funded by the National Science Foundation
- Cosmic dust collected by NASA aircraft
- Solar wind atoms collected by the Genesis spacecraft
- Comet particles collected by the Stardust spacecraft
- Interstellar dust particles collected by the Stardust spacecraft[8]

52 kilograms (115 lb) of the 382 kilograms (842 lb) of lunar samples returned by the Apollo program are stored at the White Sands Test Facility.[4] Other small samples have been distributed to foreign heads of state, U.S. states, museums, and other institutions. NASA has also made a number of educational packs available for exhibition and educational purposes, each consisting of a disc of six small rock and soil samples in a lucite disc and a pack of thin petrological sections. [9]

In addition to the lunar samples returned by the Apollo missions, an additional 300 grams (11 oz) of lunar samples were returned to Earth by three automated Soviet spacecraft, Luna 16, Luna 20, and Luna 24.[5]

## Access to facility and samples[edit]

Non-pristine samples returned to the lab after research was completed

Approximately 100 people visit the facility annually for research or educational purposes, and the facility provides samples to hundreds of others each year for research or educational purposes.[6]

Researchers seeking samples submit proposals, which are evaluated by an independent peer review panel. 40 to 50 such proposals are approved each year and approximately 400 lunar samples (most weighing less than one gram) are sent to these scientists.[7]

## See also[edit]

- Geology of the Moon
- Moon rock
- Lyndon B. Johnson Space Center
- The Case of the Missing Moon Rocks, 2012 non-fiction book
- Moon for Sale, 2007 documentary

## References[edit]

1. ^ a b c d e f g h
   Allton, Judy (July 1994). "25 Years of Curating Moon Rocks" (PDF). Lunar News. Astromaterials Acquisition and Curation Office, Lyndon B. Johnson Space Center, NASA. p. 4. Retrieved 29 June 2012.
2. ^ Compton, William David (1989). "Handling Samples from the Moon". Where No Man Has Gone Before: A History of Apollo Lunar Surface Explorations. U.S. Government Printing Office. pp. 44–46. Archived from the original on 30 October 2004. Retrieved 5 July 2012.
3. ^ a b c d e f Kristen Erickson (16 July 2009). Amiko Kauderer (ed.). "Rock Solid: JSC's Lunar Sample Lab Turns 30". 40th Anniversary of Apollo Program. NASA. Retrieved 29 June 2012.
4. ^ a b Brian Dunbar (29 March 2008). Gabriel Martinez (ed.). "White Sands Test Facility is the Curator for Apollo Lunar Samples". NASA. Retrieved 22 December 2017.
5. ^ a b c d e f g h Carlton Allen (29 April 2011). Nancy S. Todd (ed.). "Curator's Tour of the Lunar Sample Laboratory Facility". Astromaterials Acquisition and Curation Office, Lyndon B. Johnson Space Center, NASA. Retrieved 22 December 2017.
6. ^ a b c d e Carlton Allen (29 April 2011). Nancy S. Todd (ed.). "Lunar Sample Laboratory Facility". Astromaterials Acquisition and Curation Office, Lyndon B. Johnson Space Center, NASA. Retrieved 29 June 2012.
7. ^ a b Gugliotta, Guy (28 July 2008). "The Keepers of the Moon". New York Times. Retrieved 27 June 2012.
8. ^ Carlton Allen; Judith Allton; Gary Lofgren; Kevin Righter; Michael Zolensky (2011). "Curating NASA's Extraterrestrial Samples – Past, Present, and Future" (PDF). Solar System Sample Return Mission 2011. Astromaterials Acquisition and Curation Office, Lyndon B. Johnson Space Center, NASA. Retrieved 29 June 2012.
9. ^ Carlton Allen (2 April 2012). Nancy S. Todd (ed.). "How to Request Lunar Samples". Astromaterials Acquisition and Curation Office, Lyndon B. Johnson Space Center, NASA. Retrieved 29 June 2012.

- This article incorporates public domain material from websites or documents of the National Aeronautics and Space Administration.

## Further reading[edit]

- Hagen, Carmel (2012). "How an Intern Stole NASA's Moon Rocks". gizmodo.com. Retrieved 8 July 2012.

## External links[edit]

- Lunar Sample Laboratory Tour
- Lunar Sample Information (JSC)
- History NASA Apollo

Retrieved from "https://en.wikipedia.org/w/index.php?title=Lunar_Sample_Laboratory_Facility&oldid=1176876045"
Categories:

- Buildings and structures in Houston
- Johnson Space Center
- NASA facilities
- Lunar samples

Hidden categories:

- Articles with short description
- Short description matches Wikidata
- Coordinates on Wikidata
- Wikipedia articles incorporating text from NASA
- Use American English from January 2014
- All Wikipedia articles written in American English